package
Version:
v0.0.0-...-a129e4f
Opens a new window with list of versions in this module.
Published: Apr 30, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Adward struct {
Author string `json:"author"`
Rank int `json:"rank"`
Link string `json:"link"`
Time string `json:"time"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.